@@ -35,13 +35,14 @@ import urllib
 # The '.SE' pseudo macro is described in the function: cplusplus2groff
 rps = [
         # Header, Name
-        (r'\s*<div id="I_type"[^>]*>(.*?)\s*</div>\s*<h1>(.*?)</h1>\s*'
-         r'<div id="I_file"[^>]*>(.*?)</div>\s*<div class="C_prototype"[^>]*>'
+        (r'\s*<div id="I_type"[^>]*>(.*?)\s*</div>\s*'
+         r'<div id="I_file"[^>]*>(.*?)</div>\s*'
+         r'<h1>(.*?)</h1>\s*<div class="C_prototype"[^>]*>'
          r'(.*?)</div>\s*<div id="I_description"[^>]*>(.*?)</div>',
-         r'.TH "\2" 3 "%s" "cplusplus.com" "C++ Programmer\'s Manual"\n'
-         r'\n.SH NAME\n\2 - \5\n'
+         r'.TH "\3" 3 "%s" "cplusplus.com" "C++ Programmer\'s Manual"\n'
+         r'\n.SH NAME\n\3 - \5\n'
          r'\n.SE\n.SH TYPE\n\1\n'
-         r'\n.SE\n.SH SYNOPSIS\n#include \3\n.sp\n\4\n'
+         r'\n.SE\n.SH SYNOPSIS\n#include \2\n.sp\n\4\n'
          r'\n.SE\n.SH DESCRIPTION\n' % datetime.date.today(), re.S),
         (r'\s*<div id="I_type"[^>]*>(.*?)\s*</div>\s*<h1>(.*?)</h1>\s*'
          r'<div id="I_file"[^>]*>(.*?)</div>\s*<div id="I_description"[^>]*>'
@@ -130,7 +131,8 @@ rps = [
         (r'&amp;', r'&', 0),
         (r'&nbsp;', r' ', 0),
         (r'\\([^n])', r'\\\\\1', 0),
-        #(u'\x0d([^)])', r'\n.br\n\1', 0),
+        #: vector::data SYNOPSIS section has \x0d separting two lines
+        (u'\x0d([^)])', r'\n.br\n\1', 0),
         (u'\x0d', r'', 0),
         (r'>/">', r'', 0),
         (r'/">', r'', 0),
@@ -287,6 +289,14 @@ def get_width():
     if width >= columns -2: width = columns -2
     return width
 
+def func_test():
+    """Test if there is major format changes in cplusplus.com"""
+    ifs = urllib.urlopen('http://www.cplusplus.com/printf')
+    result = cplusplus2groff(ifs.read())
+    assert '.SH NAME' in result
+    assert '.SH TYPE' in result
+    assert '.SH DESCRIPTION' in result
+
 def test():
     """Simple Text"""
     name = raw_input('What manual page do you want? ')
